pub enum ExtendedConsensusError {
ConErr(ConsensusError),
DBErr(BoxError),
TxsIncludedWithBlockIncorrect,
OneOrMoreBatchVerificationStatementsInvalid,
NoBlocksToVerify,
}Expand description
An Error returned from one of the consensus services.
Variants
ConErr(ConsensusError)
A consensus error.
DBErr(BoxError)
A database error.
TxsIncludedWithBlockIncorrect
The transactions passed in with this block were not the ones needed.
OneOrMoreBatchVerificationStatementsInvalid
One or more statements in the batch verifier was invalid.
NoBlocksToVerify
A request to verify a batch of blocks had no blocks in the batch.