Function initialize_blockchain_context
pub async fn initialize_blockchain_context<D>(
cfg: ContextConfig,
database: D,
) -> Result<BlockchainContextService, ContextCacheError>where
D: Database + Clone + Send + Sync + 'static,
<D as Service<BlockchainReadRequest>>::Future: Send + 'static,Expand description
Initialize the blockchain context service.
This function will request a lot of data from the database so it may take a while.