BlockchainContext

Struct BlockchainContext 

pub struct BlockchainContext {
    pub cumulative_difficulty: u128,
    pub context_to_verify_block: ContextToVerifyBlock,
    /* private fields */
}
Raw blockchain context, gotten from BlockchainContext. This data may turn invalid so is not ok to keep around. You should keep around BlockchainContext instead.

Fields

cumulative_difficulty: u128

The current cumulative difficulty.

context_to_verify_block: ContextToVerifyBlock

Context to verify a block, as needed by [cuprate_consensus_rules]

Implementations



impl BlockchainContext

pub fn long_term_effective_median_weight(&self) -> usize

Returns the long-term effective median block weight used for relay-fee calculations.

pub fn current_adjusted_timestamp_for_time_lock(&self) -> u64

Returns the timestamp the should be used when checking locked outputs.

ref: https://cuprate.github.io/monero-book/consensus_rules/transactions/unlock_time.html#getting-the-current-time

pub fn next_block_long_term_weight(&self, block_weight: usize) -> usize

Returns the next blocks long term weight from its block weight.