Struct BlockchainContext
pub struct BlockchainContext {
pub cumulative_difficulty: u128,
pub context_to_verify_block: ContextToVerifyBlock,
/* private fields */
}Expand description
Raw blockchain context, gotten from BlockchainContext. This data may turn invalid so is not ok to keep
around. You should keep around BlockchainContext instead.
Fields
cumulative_difficulty: u128The current cumulative difficulty.
context_to_verify_block: ContextToVerifyBlockContext to verify a block, as needed by [cuprate_consensus_rules]
Implementations
impl BlockchainContext
impl BlockchainContext
pub fn long_term_effective_median_weight(&self) -> usize
pub fn long_term_effective_median_weight(&self) -> usize
Returns the long-term effective median block weight used for relay-fee calculations.
pub fn current_adjusted_timestamp_for_time_lock(&self) -> u64
pub fn current_adjusted_timestamp_for_time_lock(&self) -> u64
Returns the timestamp the should be used when checking locked outputs.
pub fn next_block_long_term_weight(&self, block_weight: usize) -> usize
pub fn next_block_long_term_weight(&self, block_weight: usize) -> usize
Returns the next blocks long term weight from its block weight.